/*
 * Copyright (C) 2018 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto2";
package com.android.server.biometrics.face;

import "frameworks/base/core/proto/android/privacy.proto";

option java_multiple_files = true;
option java_outer_classname = "FaceServiceProto";

message FaceServiceDumpProto {
    option (.android.msg_privacy).dest = DEST_AUTOMATIC;

    // Each log may include multiple user_id for different users.
    repeated FaceUserStatsProto users = 1;
}

message FaceUserStatsProto {
    option (.android.msg_privacy).dest = DEST_AUTOMATIC;

    // Refer to the UserHandle documentation.
    optional int32 user_id = 1;

    // The number of faces registered to this user.
    optional int32 num_faces = 2;

    // Normal face authentications stats (e.g. lockscreen).
    optional FaceActionStatsProto normal = 3;

    // Crypto authentications (e.g. to unlock password storage, make secure
    // purchases, etc).
    optional FaceActionStatsProto crypto = 4;
}

message FaceActionStatsProto {
    option (.android.msg_privacy).dest = DEST_AUTOMATIC;

    // Number of accepted faces.
    optional int32 accept = 1;

    // Number of rejected faces.
    optional int32 reject = 2;

    // Total number of acquisitions. Should be >= accept+reject due to poor
    // image acquisition in some cases (too high, too low, poor gaze, etc.)
    optional int32 acquire = 3;

    // Total number of lockouts.
    optional int32 lockout = 4;

    // Total number of permanent lockouts.
    optional int32 lockout_permanent = 5;
}
